# -*- coding: utf-8 -*-

from urllib import request

def spider(url):
    header = {'User-Agent':'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/\
    537.36 (KHTML, like Gecko) Chrome/55.0.2883.87 Safari/537.36'}
    # req = request.Request(url,headers=header)

    with request.urlopen(url) as response:
        data = response.read()
        print('Status:', response.status, response.reason)
        for k, v in response.getheaders():
            print('%s: %s' % (k, v))
        print('Data:', data.decode('utf-8'))


# -*- coding: utf-8 -*-

from echeck.log.Logger import Logger
import sys,os
from echeck.conf.config import Config
from echeck.Curlclient import Curlclient
from echeck.eping import *
from echeck.escan import EScan
from echeck.eshell import EShell

def banner():
    print('''
-----------------------------------------------------------
 _______   ______  __     __  _______   ______  __   _
(  _____)(  ____ \(  )   (  |(  _____)(  ____ \(  ) / )
| (      | (    \/|  (   )  || (      | (    \/|  (/ /
| (_____ | |      |  (___)  || (_____ | |      |    /
|  _____)| |      |   ___   ||  _____)| |      |    \
| (      | |      |  (   )  || (      | |      |  (\ \
| )_____ | (____/\|  )   (  || )_____ | (____/\|  ) \_)
|_______)(_______/|__)   (__||_______)(_______/|__)

------------------------------------------------------------
    ''')

try:
    banner()
    os.mknod("echeck_std.log")
except Exception as e:
    print ("creat file failed.",e)

log_file = open("echeck_std.log", "a")
sys.stdout = log_file


profile = "conf.yml"

if len(sys.argv) > 1:
    profile = sys.argv[1]
    print('the conf file is: %s ',profile)

props = Config(profile)  # 读取文件
url_list = props.getURLS()
ip_list = props.getIPList()
ping_timeout = props.getPingTimeout()
ping_count = props.getPingCount()
host_list = props.getHostAndPort()
eshell_cmds = props.getEShellCommands()
indexFile = props.getIndexFile()
logFile = props.getLogFile()
loggerLevel = props.getLoggerLevel()
logger_name = props.getLoggerName()
log = Logger(logFile)
logger = log.getLogger(logger_name, loggerLevel)


def check_url():
    startTime = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
    logger.info('/~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
    logger.info("excute main ,the default encoding is %s start time %s", sys.getdefaultencoding(), startTime)
    client = Curlclient(url_list, indexFile)
    res_list = client.docheck()
    for res in res_list:
        logger.info('/*************************************************')
        logger.info(" *URL_LIST：%s" % (res['url']))
        if res['res'] == 1:
            logger.info(" *HTTP状态码：%s" % (res['HTTP_CODE']))
            logger.info(" *DNS解析时间：%.2f ms" % (res['NAMELOOKUP_TIME'] * 1000))
            logger.info(" *建立连接时间：%.2f ms" % (res['CONNECT_TIME'] * 1000))
            logger.info(" *准备传输时间：%.2f ms" % (res['PRETRANSFER_TIME'] * 1000))
            logger.info(" *传输开始时间：%.2f ms" % (res['STARTTRANSFER_TIME'] * 1000))
            logger.info(" *传输结束总时间：%.2f ms" % (res['TOTAL_TIME'] * 1000))
            logger.info(" *下载数据包大小：%d bytes/s" % (res['SIZE_DOWNLOAD']))
            logger.info(" *HTTP头部大小：%d byte" % (res['HEADER_SIZE']))
            logger.info(" *平均下载速度：%d bytes/s" % (res['SPEED_DOWNLOAD']))
        else:
            logger.info(" *失败信息：%s" % (res['mesg']))
        logger.info('*************************************************/')
    endTime = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
    logger.info("excute main ,end time %s", endTime)
    logger.info('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~/\n')

def check_ip():
    for ip in ip_list:
        verbose_ping(ip,ping_count,timeout=ping_timeout,logger=logger)

def scan_port():
    escan = EScan(host_list)
    escan.loopSacn(logger=logger)

def exec_comand():
    for shell_box in eshell_cmds:
        shell_cell = shell_box['shell_cell']
        eshell = EShell(shell_cell['ip'],shell_cell['label'],shell_cell['port'],shell_cell['user_name'],shell_cell['password'])
        eshell.exec_commands(shell_cell['exec_command'],logger=logger)
# if __name__ == '__main__':
#     scan_port()


# -*- coding: utf-8 -*-

import os
import yaml

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
class Config():
    def __init__(self,conf_file):
        file = open(conf_file,encoding='utf-8')
        self.conf = yaml.load(file)
        self.ecurl = self.conf.get('ecurl')
        self.server_info = self.conf.get('server')
        self.log_info = self.server_info['log']
        self.eping = self.conf.get('eping')
        self.escan = self.conf.get('escan')
        self.eshell = self.conf.get('eshell')

    def getURLS(self):
        return self.ecurl['url']

    def getLogFile(self):
        return self.log_info['log_file']

    def getLoggerName(self):
        return self.log_info['logger_name']

    def getLoggerLevel(self):
        return self.log_info['logger_level']

    def getIndexFile(self):
        return self.ecurl['index_file']

    def getIPList(self):
        return self.eping['ip']

    def getPingCount(self):
        return self.eping['count']

    def getPingTimeout(self):
        return self.eping['timeout']

    def getHostAndPort(self):
        return self.escan

    def getEShellCommands(self):
        return self.eshell

# conf = Config('/Users/zhangpenghong/Documents/workspace/easy_check/conf.yml')
# # urls = conf.getECHECK()
# # print(conf.getURLS())
# print(conf.getHostAndPort())


# -*- coding: utf-8 -*-

class TestECurl():
    def test_ecurl(self):
        from echeck.Curlclient import Curlclient
        url_list = ['https://www.baidu.com','http://www.pathcurve.cn']
        client = Curlclient(url_list, 'indexfile')
        res_list = client.docheck()
        for res in res_list:
            print(" *URL_LIST：%s" % (res['url']))
            if res['res'] == 1:
                print(" *HTTP状态码：%s" % (res['HTTP_CODE']))
                print(" *DNS解析时间：%.2f ms" % (res['NAMELOOKUP_TIME'] * 1000))
                print(" *建立连接时间：%.2f ms" % (res['CONNECT_TIME'] * 1000))
                print(" *准备传输时间：%.2f ms" % (res['PRETRANSFER_TIME'] * 1000))
                print(" *传输开始时间：%.2f ms" % (res['STARTTRANSFER_TIME'] * 1000))
                print(" *传输结束总时间：%.2f ms" % (res['TOTAL_TIME'] * 1000))
                print(" *下载数据包大小：%d bytes/s" % (res['SIZE_DOWNLOAD']))
                print(" *HTTP头部大小：%d byte" % (res['HEADER_SIZE']))
                print(" *平均下载速度：%d bytes/s" % (res['SPEED_DOWNLOAD']))
            else:
                print(" *失败信息：%s" % (res['mesg']))


# -*- coding: utf-8 -*-

import re
import tempfile
import os

def replace_property(file_name, from_regex, to_str, append_on_not_exists=True):
    tmpfile = tempfile.TemporaryFile()

    if os.path.exists(file_name):
        r_open = open(file_name, 'r')
        pattern = re.compile(r'' + from_regex)
        found = None
        for line in r_open:
            if pattern.search(line) and not line.strip().startswith('#'):
                found = True
                line = re.sub(from_regex, to_str, line)
            tmpfile.write(line.encode(encoding='utf-8'))
        if not found and append_on_not_exists:
            temp = to_str
            tmpfile.write(temp.encode(encoding='utf-8'))
        r_open.close()
        tmpfile.seek(0)

        content = tmpfile.read()

        if os.path.exists(file_name):
            os.remove(file_name)

        w_open = open(file_name, 'w')
        w_open.write(str(content))
        w_open.close()

        tmpfile.close()
    else:
        print("file %s not found" % file_name)

def prop_parse(file_name):
    return Properties(file_name)

class Properties:

    def __init__(self, file_name):
        self.file_name = file_name
        self.properties = {}
        try:
            fopen = open(self.file_name, 'r')
            for line in fopen:
                line = line.strip()
                if line.find('=') > 0 and not line.startswith('#'):
                    strs = line.split('=')
                    self.properties[strs[0].strip()] = strs[1].strip()
        except Exception as e:
            raise e
        else:
            fopen.close()

    def has_key(self, key):
        return key in self.properties

    def get(self, key, default_value=''):
        if key in self.properties:
            return self.properties[key]
        return default_value

    def put(self, key, value):
        self.properties[key] = value
        replace_property(self.file_name, key + '=.*', key + '=' + value, True)


# -*- coding: utf-8 -*-
import pycurl
import sys

class Curlclient:

    def __init__(self,urls,indexFile):
        self.URL_LIST = urls
        self.INDEXFILE = indexFile
        self.CURL_LIST = []

    def docheck(self):
        c = pycurl.Curl()
        for url in self.URL_LIST:
            res = {'res':1,'mesg':'succeed','url':url}
            c.setopt(pycurl.URL,url)
            # 连接超时时间,5秒
            c.setopt(pycurl.CONNECTTIMEOUT, 5)

            # 下载超时时间,5秒
            c.setopt(pycurl.TIMEOUT, 5)
            c.setopt(pycurl.FORBID_REUSE, 1)
            c.setopt(pycurl.MAXREDIRS, 1)
            c.setopt(pycurl.NOPROGRESS, 1)
            c.setopt(pycurl.DNS_CACHE_TIMEOUT, 30)
            indexfile = open(self.INDEXFILE, "wb")
            c.setopt(pycurl.WRITEHEADER, indexfile)
            c.setopt(pycurl.WRITEDATA, indexfile)

            try:
                c.perform()
            except Exception as e:
                res['res'] = 0
                res['mesg'] = str(e)
                indexfile.close()
                c.close()
            if res['res'] == 1:
                res['NAMELOOKUP_TIME'] = c.getinfo(c.NAMELOOKUP_TIME)
                res['CONNECT_TIME'] = c.getinfo(c.CONNECT_TIME)
                res['PRETRANSFER_TIME'] = c.getinfo(c.PRETRANSFER_TIME)
                res['STARTTRANSFER_TIME'] = c.getinfo(c.STARTTRANSFER_TIME)
                res['TOTAL_TIME'] = c.getinfo(c.TOTAL_TIME)
                res['HTTP_CODE'] = c.getinfo(c.HTTP_CODE)
                res['SIZE_DOWNLOAD'] = c.getinfo(c.SIZE_DOWNLOAD)
                res['HEADER_SIZE'] = c.getinfo(c.HEADER_SIZE)
                res['SPEED_DOWNLOAD'] = c.getinfo(c.SPEED_DOWNLOAD)
            res['curl'] = c
            self.CURL_LIST.append(res)
        return self.CURL_LIST


# -*- coding: utf-8 -*-

class PingError(Exception):
    pass


class TimeExceeded(PingError):
    pass


class TimeToLiveExpired(TimeExceeded):
    def __init__(self, message="Time exceeded: Time To Live expired"):
        super().__init__(message)


class HostUnknown(PingError):
    def __init__(self, dest_addr):
        message = "Cannot resolve {}: Unknown host".format(dest_addr)
        super().__init__(message)


class Timeout(PingError):
    def __init__(self, timeout):
        message = "Request timeout for ICMP packet. ({}s)".format(timeout)
        super().__init__(message)



#!/usr/bin/env python

import sys
import socket
import struct
import select
import time
import threading
import logging
from echeck.ec_exception import PingError,TimeExceeded,TimeToLiveExpired,HostUnknown,Timeout
from echeck.enums import ICMP_DEFAULT_CODE, IcmpType, IcmpTimeExceededCode, IcmpDestinationUnreachableCode

DEBUG = False  # DEBUG: Show debug info for developers. (default False)
EXCEPTIONS = False  # EXCEPTIONS: Raise exception when delay is not available.

IP_HEADER_FORMAT = "!BBHHHBBHII"
ICMP_HEADER_FORMAT = "!BBHHH"  # According to netinet/ip_icmp.h. !=network byte order(big-endian), B=unsigned char, H=unsigned short
ICMP_TIME_FORMAT = "!d"  # d=double


if sys.platform == "win32":
    default_timer = time.clock  # On Windows, the best timer is time.clock()
else:
    default_timer = time.time  # On most other platforms the best timer is time.time()


def _debug(*args):
    if DEBUG:
        message = "[DEBUG]"
        print(message, *args)


def ones_comp_sum16(num1: int, num2: int) -> int:
    """Calculates the 1's complement sum for 16-bit numbers.

    Args:
        num1: 16-bit number.
        num2: 16-bit number.

    Returns:
        The calculated result.
    """

    carry = 1 << 16
    result = num1 + num2
    return result if result < carry else result + 1 - carry


def checksum(source: bytes) -> int:
    """Calculates the checksum of the input bytes.

    RFC1071: https://tools.ietf.org/html/rfc1071
    RFC792: https://tools.ietf.org/html/rfc792

    Args:
        source: The input to be calculated.

    Returns:
        Calculated checksum.
    """
    if len(source) % 2:  # if the total length is odd, padding with one octet of zeros for computing the checksum
        source += b'\x00'
    sum = 0
    for i in range(0, len(source), 2):
        sum = ones_comp_sum16(sum, (source[i + 1] << 8) + source[i])
    return ~sum & 0xffff


def send_one_ping(sock: socket, dest_addr: str, icmp_id: int, seq: int, size: int):
    """Sends one ping to the given destination.

    ICMP Header (bits): type (8), code (8), checksum (16), id (16), sequence (16)
    ICMP Payload: time (double), data
    ICMP Wikipedia: https://en.wikipedia.org/wiki/Internet_Control_Message_Protocol

    Args:
        sock: Socket.
        dest_addr: The destination address, can be an IP address or a domain name. Ex. "192.168.1.1"/"example.com"
        icmp_id: ICMP packet id, usually is same as pid.
        seq: ICMP packet sequence, usually increases from 0 in the same process.
        size: The ICMP packet payload size in bytes. Note this is only for the payload part.

    Raises:
        HostUnkown: If destination address is a domain name and cannot resolved.
    """
    try:
        dest_addr = socket.gethostbyname(dest_addr)  # Domain name will translated into IP address, and IP address leaves unchanged.
    except socket.gaierror as e:
        print("Cannot resolve {}: Unknown host".format(dest_addr))
        raise HostUnknown(dest_addr) from e
    pseudo_checksum = 0  # Pseudo checksum is used to calculate the real checksum.
    icmp_header = struct.pack(ICMP_HEADER_FORMAT, IcmpType.ECHO_REQUEST, ICMP_DEFAULT_CODE, pseudo_checksum, icmp_id, seq)
    padding = (size - struct.calcsize(ICMP_TIME_FORMAT) - struct.calcsize(ICMP_HEADER_FORMAT)) * "Q"  # Using double to store current time.
    icmp_payload = struct.pack(ICMP_TIME_FORMAT, default_timer()) + padding.encode()
    real_checksum = checksum(icmp_header + icmp_payload)  # Calculates the checksum on the dummy header and the icmp_payload.
    # Don't know why I need socket.htons() on real_checksum since ICMP_HEADER_FORMAT already in Network Bytes Order (big-endian)
    icmp_header = struct.pack(ICMP_HEADER_FORMAT, IcmpType.ECHO_REQUEST, ICMP_DEFAULT_CODE, socket.htons(real_checksum), icmp_id, seq)  # Put real checksum into ICMP header.
    packet = icmp_header + icmp_payload
    sock.sendto(packet, (dest_addr, 0))  # addr = (ip, port). Port is 0 respectively the OS default behavior will be used.


def receive_one_ping(sock: socket, icmp_id: int, seq: int, timeout: int) -> float or None:
    """Receives the ping from the socket.

    IP Header (bits): version (8), type of service (8), length (16), id (16), flags (16), time to live (8), protocol (8), checksum (16), source ip (32), destination ip (32).
    ICMP Packet (bytes): IP Header (20), ICMP Header (8), ICMP Payload (*).
    Ping Wikipedia: https://en.wikipedia.org/wiki/Ping_(networking_utility)
    ToS (Type of Service) in IP header for ICMP is 0. Protocol in IP header for ICMP is 1.

    Args:
        sock: The same socket used for send the ping.
        icmp_id: ICMP packet id. Sent packet id should be identical with received packet id.
        seq: ICMP packet sequence. Sent packet sequence should be identical with received packet sequence.
        timeout: Timeout in seconds.

    Returns:
        The delay in seconds or None on timeout.

    Raises:
        TimeToLiveExpired: If the Time-To-Live in IP Header is not large enough for destination.
        TimeExceeded: If time exceeded but Time-To-Live does not expired.
    """
    ip_header_slice = slice(0, struct.calcsize(IP_HEADER_FORMAT))  # [0:20]
    icmp_header_slice = slice(ip_header_slice.stop, ip_header_slice.stop + struct.calcsize(ICMP_HEADER_FORMAT))  # [20:28]
    ip_header_keys = ('version', 'tos', 'len', 'id', 'flags', 'ttl', 'protocol', 'checksum', 'src_addr', 'dest_addr')
    icmp_header_keys = ('type', 'code', 'checksum', 'id', 'seq')
    while True:
        selected = select.select([sock], [], [], timeout)
        if selected[0] == []:  # Timeout
            raise Timeout(timeout)
        time_recv = default_timer()
        recv_data, addr = sock.recvfrom(1024)
        ip_header_raw, icmp_header_raw, icmp_payload_raw = recv_data[ip_header_slice], recv_data[icmp_header_slice], recv_data[icmp_header_slice.stop:]
        ip_header = dict(zip(ip_header_keys, struct.unpack(IP_HEADER_FORMAT, ip_header_raw)))
        _debug("IP HEADER:", ip_header)
        icmp_header = dict(zip(icmp_header_keys, struct.unpack(ICMP_HEADER_FORMAT, icmp_header_raw)))
        _debug("ICMP HEADER:", icmp_header)
        if icmp_header['type'] == IcmpType.TIME_EXCEEDED:  # TIME_EXCEEDED has no icmp_id and icmp_seq. Usually they are 0.
            if icmp_header['code'] == IcmpTimeExceededCode.TTL_EXPIRED:
                raise TimeToLiveExpired()  # Some router does not report TTL expired and then timeout shows.
            raise TimeExceeded()
        if icmp_header['id'] == icmp_id and icmp_header['seq'] == seq:  # ECHO_REPLY should match the
            if icmp_header['type'] == IcmpType.ECHO_REQUEST:  # filters out the ECHO_REQUEST itself.
                _debug("ECHO_REQUEST filtered out.")
                continue
            if icmp_header['type'] == IcmpType.ECHO_REPLY:
                time_sent = struct.unpack(ICMP_TIME_FORMAT, icmp_payload_raw[0:struct.calcsize(ICMP_TIME_FORMAT)])[0]
                return time_recv - time_sent


def ping(dest_addr: str, timeout: int = 4, unit: str = "s", src_addr: str = None, ttl: int = 64, seq: int = 0, size: int = 56,logger = None) -> float or None:
    """
    Send one ping to destination address with the given timeout.

    Args:
        dest_addr: The destination address, can be an IP address or a domain name. Ex. "192.168.1.1"/"example.com"
        timeout: Timeout in seconds. Default is 4s, same as Windows CMD. (default 4)
        unit: The unit of returned value. "s" for seconds, "ms" for milliseconds. (default "s")
        src_addr: The IP address to ping from. This is for multi-interface clients. Ex. "192.168.1.20". (default None)
        ttl: The Time-To-Live of the outgoing packet. Default is 64, same as in Linux and macOS. (default 64)
        seq: ICMP packet sequence, usually increases from 0 in the same process. (default 0)
        size: The ICMP packet payload size in bytes. Default is 56, same as in macOS. (default 56)

    Returns:
        The delay in seconds/milliseconds or None on timeout.

    Raises:
        PingError: Any PingError will raise again if `ping3.EXCEPTIONS` is True.
    """
    with socket.socket(socket.AF_INET, socket.SOCK_RAW, socket.IPPROTO_ICMP) as sock:
        sock.setsockopt(socket.SOL_IP, socket.IP_TTL, ttl)
        if src_addr:
            sock.bind((src_addr, 0))
        icmp_id = threading.current_thread().ident & 0xFFFF
        try:
            send_one_ping(sock=sock, dest_addr=dest_addr, icmp_id=icmp_id, seq=seq, size=size)
            delay = receive_one_ping(sock=sock, icmp_id=icmp_id, seq=seq, timeout=timeout)  # in seconds
        except PingError as e:
            _debug(e)
            if EXCEPTIONS:
                raise e
            return None
        if delay is None:
            return None
        if unit == "ms":
            delay *= 1000  # in milliseconds
    return delay


def verbose_ping(dest_addr: str, count: int = 4, *args, **kwargs):
    """
    Send pings to destination address with the given timeout and display the result.

    Args:
        dest_addr: The destination address. Ex. "192.168.1.1"/"example.com"
        count: How many pings should be sent. Default is 4, same as Windows CMD. (default 4)
        *args and **kwargs: And all the other arguments available in ping() except `seq`.

    Returns:
        Formatted ping results printed.
    """
    timeout = kwargs.get("timeout")
    src = kwargs.get("src")
    unit = kwargs.setdefault("unit", "ms")
    logger = kwargs.get("logger")
    if logger is None:
        for i in range(count):
            delay = ping(dest_addr, seq=i, *args, **kwargs)
            print("Timeout > {}s".format(timeout) if timeout else "Timeout")
            print("{value}{unit}".format(value=int(delay), unit=unit))
    else:
        logger.info('/~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
        logger.info('/*************************************************')
        for i in range(count):
            output_text = "ping '{}'".format(dest_addr)
            output_text += " from '{}'".format(src) if src else ""
            output_text += " ... "
            print(output_text, end="")
            delay = ping(dest_addr, seq=i, *args, **kwargs)
            if delay is None:
                respTime = "Timeout > {}s".format(timeout) if timeout else "Timeout"
                logger.info(output_text + ' %s' % respTime)
            else:
                respTime = "{value}{unit}".format(value=int(delay), unit=unit)
                logger.info(output_text + ' %s' % respTime)

        logger.info('*************************************************/')
        logger.info('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~/\n')
        
# if __name__ == "__main__":
# 
#     verbose_ping("127.0.0.1",logger=None)
    # verbose_ping("8.8.8.8")


# -*- coding: utf-8 -*-

import getpass
import telnetlib


def do_telnet(host,username,password,finish,commands):
    tn = telnetlib.Telnet(host,port=23,timeout=10)
    tn.set_debuglevel(2)
    tn.read_until('login:')
    tn.write(username + '\n')
    tn.read_until('password:')
    tn.write(password + '\n')
    tn.read_until(finish)
    for command in commands:
        tn.write('%s\n' % command)
    tn.read_until(finish)
    tn.close()

if __name__=='__main__':
    host = 'localhost'
    username = ''
    password = ''
    finish = ':~$ '  #  命令提示符
    commands = ['echo "test"']
    do_telnet(host,username,password,finish,commands)

# HOST = "localhost"
# user = input("Enter your remote account: ")
# password = getpass.getpass()
#
# tn = telnetlib.Telnet(HOST)
#
# tn.read_until(b"login: ")
# tn.write(user.encode('ascii') + b"\n")
# if password:
#     tn.read_until(b"Password: ")
#     tn.write(password.encode('ascii') + b"\n")
#
# tn.write(b"ls\n")
# tn.write(b"exit\n")
#
# print(tn.read_all().decode('ascii'))


import paramiko

class EShell():
    def __init__(self,host,label,port,user_name,password):
        self.HOSTNAME = host
        self.PORT = port
        self.USER_NAME = user_name
        self.PASSWORD = password
        self.LABEL = label

    def exec_commands(self,cmds,**kwargs):
        logger = kwargs.get("logger")
        ssh = paramiko.SSHClient()
        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        ssh.connect(self.HOSTNAME, self.PORT, self.USER_NAME, self.PASSWORD)

        logger.info('/~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
        logger.info('/*************************************************')
        logger.info("Address: {}".format(self.HOSTNAME))
        logger.info("Label: {}".format(self.LABEL))
        for cmd in cmds:
            stdin, stdout, stderr = ssh.exec_command(cmd)
            logger.info("cmd:{}\t".format(cmd))
            result = stdout.readlines()
            logger.info("result: ")
            for re in result:
                logger.info(("  *{}\t".format(re)).replace('\n',''))
        ssh.close()
        logger.info('*************************************************/')
        logger.info('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~/\n')


# -*- coding:utf-8 -*-
from setuptools import setup, find_packages
import os

with open("README_EN.md", "r") as fh:
    long_description = fh.read()

# with open('LICENSE') as fp:
#     license = fp.read()

# os.system('export PYCURL_SSL_LIBRARY=openssl')

setup(
    name='echeck',
    version='2.0.3',
    description='简单易用的批量环境检查工具',
    long_description=long_description,
    # long_description_content_type="text/x-rst",
    long_description_content_type="text/markdown",
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3 :: Only',
    ],
    author='Rocky',
    url='https://github.com/rockyCheung/easy_echeck.git',
    author_email='274935730@qq.com',
    license='PSF',
    packages=find_packages(exclude=['contrib', 'docs', 'test']),
    install_requires=['pycurl>=7.43.0.2','beautifulsoup4>=4.7.1','soupsieve>=1.8','wheel>=0.33.1','setuptools>=40.8.0',
                      'PyYAML>=3.13','nmap>=0.0.1','paramiko>=2.4.2','asn1crypto>=0.24.0','bcrypt>=3.1.6','cffi>=1.12.2',
                      'cryptography>=2.4.2','paramiko>=2.4.2','pyasn1>=0.4.5','pycparser>=2.19','pynacl>=1.3.0','six>=1.12.0',
                      'pytest>=4.3.1'],
    package_data={
        # If any package contains *.txt or *.rst files, include them:
        '': ['*.txt', '*.rst','tmplate_conf.yml','*.md'],
        # And include any *.msg files found in the 'hello' package, too:
        'tip': ['*.msg'],
    },
#    include_package_data=False,
#     py_modules=["CurlClient", "ec_exception", "enums"],
    zip_safe=True,
    python_requires='>=3',
    scripts = [],
    entry_points = {
        'console_scripts': [
            'ecurl = echeck.ec_bin:check_url',
            'eping = echeck.ec_bin:check_ip',
            'escan = echeck.ec_bin:scan_port',
            'eshell = echeck.ec_bin:exec_comand'
         ]
     }
)


# -*- coding:utf-8 -*-
import logging
import logging.handlers

"""
# logger类
"""
class Logger:
    def __init__(self,log_file):
        self.handler = logging.handlers.RotatingFileHandler(log_file,mode='w', maxBytes=1024 * 1024, backupCount=5)  # 实例化handler
        self.fmt = '%(asctime)s - %(filename)s:%(lineno)s - %(name)s - %(message)s'
        self.formatter = logging.Formatter(self.fmt)  # 实例化formatter
        self.handler.setFormatter(self.formatter)  # 为handler添加formatter

    def getLogger(self,loggerName,loggerLevel):
        logger = logging.getLogger(loggerName)
        logger.addHandler(self.handler)
        logger.setLevel(self.debugLevel(loggerLevel))
        return logger

    def debugLevel(self,level):
        if level=="DEBUG":
            return logging.DEBUG
        else:
            return logging.INFO

# log = Logger('/Users/zhangpenghong/Documents/workspace/easy_check/echeck/echeck.log')
# lgggera = log.getLogger('main','DEBUG')
# count = 1
# while count < 10:
#     lgggera.info('ssss')


#!/usr/bin/python
import socket
import sys
import argparse
from sys import platform
import os
import time
import re


def start_system():
    if platform.startswith('linux') or platform.startswith('darwin'):
        os.system("clear")
        return

    else:
        os.system("cls")
        sys.exit(1)


def all_services():
    return {
        20: "FTP-data",
        21: "FTP",
        22: "SSH",
        23: "TelNet",
        25: "SMTP",
        26: "RSFTP",
        37: "Time",
        39: "RLP",
        43: "whois",
        53: "DNS",
        57: "MTP",
        67: "DHCP",
        68: "DHCP",
        80: "HTTP",
        81: "SKYPE",
        88: "Kerberos",
        95: "supdup",
        107: "rtelnet",
        111: "sunrpc",
        115: "SFTP",
        118: "SQL services",
        119: "NNTP",
        135: "RPC",
        137: "NetBios",
        443: "HTTPS",
        445: "microsoftDS",
        514: "SysLog",
        901: "Samba",
        1194: "OpenVPN",
        1433: "ms-sql-s",
        1521: "Oracle DB",
        2000: "cisco-sccp",
        2010: "pipe-server",
        2049: "NFS",
        2082: "Cpanel",
        3306: "MySQL",
        5222: "xmpp-client",
        5269: "xmpp-server",
        5432: "PostgreSQL",
        7001: "Weblogic",
        8080: "Tomcat",
        9080: "Websphere",
        10050: "zabbix-agent",
        10051: "zabbix-trapper"
    }


class EScan():
    def __init__(self,hostList):
        self.hostList = hostList

    def attempt_connections(self,host):
        """Attempts to connect to the ports pre defined in the all_services function
        :param host the connection target host
        """

        t1 = time.time()
        open_port = []
        for port in host['port']:
            scan_result = {}
            try:
                scan_result['port'] = port
                client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                client.settimeout(0.05)

                sohost = socket.gethostbyname(host['ip'])
                errno_value = client.connect_ex((sohost, port))
                if errno_value == 0:
                    scan_result['statue'] = 1
                    client.close
                else:
                    scan_result['statue'] = 0
                t2 = time.time()
                total_time = "\nScanned in {:.2f} seconds".format(t2 - t1)
            except Exception as e:
                print('scan error:',e)
                total_time = "\nScanned error {} ".format(e)
                scan_result['statue'] = 0
            open_port.append(scan_result)
        return open_port, sohost, total_time


    def print_results(self, sohost,label, open_ports, logger):
        """Prints the results the results based on the open ports
        :param sohost: the connection target sohost
        :param open_ports: a list containing the open ports(ports must be int)
        """
        logger.info('/~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
        logger.info('/*************************************************')
        logger.info("Address: {}".format(sohost))
        logger.info("Label: {}".format(label))
        logger.info("Host: {0} \t {1}".format(sohost, socket.gethostbyname(sohost)[0]))

        if len(open_ports) == 0:
            logger.info("Nothing OPEN")

        else:
            for port in open_ports:
                service_name = ''
                try:
                    service_name = all_services()[port['port']]
                except Exception as e:
                    print('TypeError,the service: {} is undefined'.format(port['port']))

                if port['statue'] == 1:
                    logger.info("Port:{}\tService: {}\t Status:  OPEN".format(port['port'],service_name))
                else:
                    logger.info("Port:{}\tService: {}\t Status:  CLOSE".format(port['port'],service_name))
        logger.info('*************************************************/')
        logger.info('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~/\n')

    def loopSacn(self,**kwargs):
        start_system()
        logger = kwargs.get("logger")
        #logger.info(self.hostList)
        for hostInfo in self.hostList:
            open_ports,host,total_time = self.attempt_connections(hostInfo['host'])
            #logger.info(hostInfo)
            self.print_results(host,hostInfo['host']['label'], open_ports,logger)
# if __name__ == "__main__":
#     host = {'ip':'127.0.0.1','label':'host','port':[8080,80,5900]}
#     e = EScan(hostList = None)
#     print(e.attempt_connections(host))